pub enum InitError {
UnsupportedPlatform,
InvalidModelRoot,
NeuralEngineUnavailable,
}Expand description
Failure to initialize a Core ML backend instance.
Variants
UnsupportedPlatform
The backend is only executable on macOS 14 or newer.
InvalidModelRoot
The configured model root is missing, not a directory, or not representable as UTF-8.
Core ML does not report an accessible Apple Neural Engine.